==> scala-k8s-objects_sjs1_2.13-0.4.0-sources.jar: io/k8s/api/events/v1/EventList.scala <==
package io.k8s.api.events.v1

import dev.hnaderi.k8s._
import dev.hnaderi.k8s.utils._

/** EventList is a list of Event objects. */
final case class EventList(
  items : Seq[io.k8s.api.events.v1.Event],
  metadata : Option[io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta] = None
) extends KObject {
  protected val _resourceKind = ResourceKind("events.k8s.io", "EventList", "v1")


  /** Returns a new data with items set to new value */
  def withItems(value: Seq[io.k8s.api.events.v1.Event]) : EventList = copy(items = value)
  /** Appends new values to items */
  def addItems(newValues: io.k8s.api.events.v1.Event*) : EventList = copy(items = items ++ newValues)
  /** transforms items to result of function */
  def mapItems(f: Seq[io.k8s.api.events.v1.Event] => Seq[io.k8s.api.events.v1.Event]) : EventList = copy(items = f(items))

  /** Returns a new data with metadata set to new value */
  def withMetadata(value: io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta) : EventList = copy(metadata = Some(value))
  /** if metadata has a value, transforms to the result of function*/
  def mapMetadata(f: io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta => io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta) : EventList = copy(metadata = metadata.map(f))

  override def foldTo[T : Builder] : T = EventList.encoder.apply(this)
}

object EventList {

    implicit val encoder : Encoder[io.k8s.api.events.v1.EventList] = new Encoder[io.k8s.api.events.v1.EventList] {
        def apply[T : Builder](o: io.k8s.api.events.v1.EventList) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("items", o.items)
            .write("metadata", o.metadata)
            .write("kind", o.kind)
            .write("apiVersion", o.apiVersion)
            .build
        }
    }

    implicit val decoder: Decoder[EventList] = new Decoder[EventList] {
      def apply[T : Reader](t: T): Either[String, EventList] = for {
          obj <- ObjectReader(t)
          items <- obj.read[Seq[io.k8s.api.events.v1.Event]]("items")
          metadata <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta]("metadata")
      } yield EventList (
          items = items,
          metadata = metadata
        )
    }
}

==> scala-k8s-objects_sjs1_3-0.3.0-sources.jar: io/k8s/api/events/v1/EventList.scala <==
package io.k8s.api.events.v1

import dev.hnaderi.k8s._
import dev.hnaderi.k8s.utils._

/** EventList is a list of Event objects. */
final case class EventList(
  items : Seq[io.k8s.api.events.v1.Event],
  metadata : Option[io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta] = None
) extends KObject {
  protected val _resourceKind = ResourceKind("events.k8s.io", "EventList", "v1")


  /** Returns a new data with items set to new value */
  def withItems(value: Seq[io.k8s.api.events.v1.Event]) : EventList = copy(items = value)
  /** Appends new values to items */
  def addItems(newValues: io.k8s.api.events.v1.Event*) : EventList = copy(items = items ++ newValues)
  /** transforms items to result of function */
  def mapItems(f: Seq[io.k8s.api.events.v1.Event] => Seq[io.k8s.api.events.v1.Event]) : EventList = copy(items = f(items))

  /** Returns a new data with metadata set to new value */
  def withMetadata(value: io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta) : EventList = copy(metadata = Some(value))
  /** if metadata has a value, transforms to the result of function*/
  def mapMetadata(f: io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta => io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta) : EventList = copy(metadata = metadata.map(f))

  override def foldTo[T : Builder] : T = EventList.encoder[T].apply(this)
}

object EventList {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.events.v1.EventList, T] = new Encoder[io.k8s.api.events.v1.EventList, T] {
        def apply(o: io.k8s.api.events.v1.EventList) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("items", o.items)
            .write("metadata", o.metadata)
            .write("kind", o.kind)
            .write("apiVersion", o.apiVersion)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, EventList] = new Decoder[T, EventList] {
      def apply(t: T): Either[String, EventList] = for {
          obj <- ObjectReader(t)
          items <- obj.read[Seq[io.k8s.api.events.v1.Event]]("items")
          metadata <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta]("metadata")
      } yield EventList (
          items = items,
          metadata = metadata
        )
    }
}
